import { FunctionValueGenerator, ValueGenerator } from "./functions/ValueGenerator";
import { Behavior } from "./behaviors/Behavior";
import { Particle } from "./Particle";
import { ParticleEmitter } from "./ParticleEmitter";
import { EmitterShape, ShapeJSON } from "./EmitterShape";
import { Blending, Matrix3, Texture } from "three";
import { ColorGenerator, FunctionColorGenerator } from "./functions/ColorGenerator";
import { FunctionJSON } from "./functions/FunctionJSON";
export interface ParticleSystemParameters {
    autoDestroy?: boolean;
    looping?: boolean;
    duration?: number;
    maxParticle?: number;
    shape?: EmitterShape;
    startLife?: ValueGenerator | FunctionValueGenerator;
    startSpeed?: ValueGenerator | FunctionValueGenerator;
    startRotation?: ValueGenerator | FunctionValueGenerator;
    startSize?: ValueGenerator | FunctionValueGenerator;
    startColor?: ColorGenerator | FunctionColorGenerator;
    emissionOverTime?: ValueGenerator | FunctionValueGenerator;
    emissionOverDistance?: ValueGenerator | FunctionValueGenerator;
    behaviors?: Array<Behavior>;
    texture?: Texture;
    startTileIndex?: number;
    uTileCount?: number;
    vTileCount?: number;
    blending?: Blending;
    worldSpace?: boolean;
}
export interface ParticleSystemJSONParameters {
    autoDestroy: boolean;
    looping: boolean;
    duration: number;
    maxParticle: number;
    shape: ShapeJSON;
    startLife: FunctionJSON;
    startSpeed: FunctionJSON;
    startRotation: FunctionJSON;
    startSize: FunctionJSON;
    startColor: FunctionJSON;
    emissionOverTime: FunctionJSON;
    emissionOverDistance: FunctionJSON;
    texture: string;
    startTileIndex: number;
    uTileCount: number;
    vTileCount: number;
    blending: number;
    behaviors: Array<any>;
    worldSpace: boolean;
}
export declare class ParticleSystem {
    autoDestroy: boolean;
    looping: boolean;
    duration: number;
    maxParticle: number;
    startLife: ValueGenerator | FunctionValueGenerator;
    startSpeed: ValueGenerator | FunctionValueGenerator;
    startRotation: ValueGenerator | FunctionValueGenerator;
    startSize: ValueGenerator | FunctionValueGenerator;
    startColor: ColorGenerator | FunctionColorGenerator;
    startTileIndex: number;
    emissionOverTime: ValueGenerator | FunctionValueGenerator;
    emissionOverDistance: ValueGenerator | FunctionValueGenerator;
    tileCount: number;
    worldSpace: boolean;
    particleNum: number;
    private time;
    private waitEmiting;
    private emitEnded;
    private markForDestroy;
    behaviors: Array<Behavior>;
    particles: Array<Particle>;
    emitterShape: EmitterShape;
    emitter: ParticleEmitter;
    texture: Texture;
    uTileCount: number;
    vTileCount: number;
    blending: Blending;
    constructor(parameters?: ParticleSystemParameters);
    spawn(): void;
    normalMatrix: Matrix3;
    endEmit(): void;
    update(delta: number): void;
    toJSON(meta: any): ParticleSystemJSONParameters;
    static fromJSON(json: ParticleSystemJSONParameters, textures: {
        [a: string]: Texture;
    }): ParticleSystem;
    addBehavior(behavior: Behavior): void;
}
